summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoOpenPane.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /lib/kofficecore/KoOpenPane.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficecore/KoOpenPane.h')
-rw-r--r--lib/kofficecore/KoOpenPane.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/kofficecore/KoOpenPane.h b/lib/kofficecore/KoOpenPane.h
index 818c6e81..64f799d8 100644
--- a/lib/kofficecore/KoOpenPane.h
+++ b/lib/kofficecore/KoOpenPane.h
@@ -39,11 +39,11 @@ class KoOpenPane : public KoOpenPaneBase
public:
/**
* Constructor
* @param tqparent the tqparent widget
* @param instance the KInstance to be used for KConfig data
* @param templateType the template-type (group) that should be selected on creation.
*/
- KoOpenPane(TQWidget *tqparent, KInstance* instance, const TQString& templateType = TQString());
+ KoOpenPane(TQWidget *parent, KInstance* instance, const TQString& templateType = TQString());
virtual ~KoOpenPane();
TQListViewItem* addPane(const TQString& title, const TQString& icon, TQWidget* widget, int sortWeight);
@@ -39,11 +39,11 @@ class KoOpenPane : public KoOpenPaneBase
/**
* Constructor
- * @param tqparent the tqparent widget
+ * @param parent the parent widget
* @param instance the KInstance to be used for KConfig data
* @param templateType the template-type (group) that should be selected on creation.